---
title: License-manager
description: Provides access to details about License Management in OpsCompass.
---

[Skip to content](https://kb.opscompass.com/knowledge/cli/license-manager#main-content)

[![Opscompass](https://kb.opscompass.com/hubfs/opscompass-logo-2024-web-small.svg)](https://opscompass.com)

- [Home](https://opscompass.com/)
- [Why Opscompass](https://opscompass.com/why-opscompass/)
- Product
  
  Show submenu for Product

    - [Inventory](https://opscompass.com/inventory/)
    - [Configuration Drift](https://opscompass.com/product/configuration-drift/)
    - [Compliance](https://opscompass.com/product/compliance/)
    - [Licenses](https://opscompass.com/solutions/licenses/)
- Solutions
  
  Show submenu for Solutions

    - [Hybrid and Multi-Cloud Visibility](https://opscompass.com/solutions/multi-cloud-visibility/)
- [About Us](https://opscompass.com/company/)

Open main navigation

Close main navigation

- [Home](https://opscompass.com/)
- [Why Opscompass](https://opscompass.com/why-opscompass/)
- Product
  
  Show submenu for Product

    - [Inventory](https://opscompass.com/inventory/)
    - [Configuration Drift](https://opscompass.com/product/configuration-drift/)
    - [Compliance](https://opscompass.com/product/compliance/)
    - [Licenses](https://opscompass.com/solutions/licenses/)
- Solutions
  
  Show submenu for Solutions

    - [Hybrid and Multi-Cloud Visibility](https://opscompass.com/solutions/multi-cloud-visibility/)
- [About Us](https://opscompass.com/company/)
- [Get a Demo](https://opscompass.com/demo/)

[Get a Demo](https://opscompass.com/demo/)

 What are you looking for?

- There are no suggestions because the search field is empty.

1. [Help Center](https://kb.opscompass.com/knowledge)
2. [Opscompass CLI](https://kb.opscompass.com/knowledge/opscompass-cli)
3. [Licensing](https://kb.opscompass.com/knowledge/opscompass-cli#licensing)

# License-manager

## Provides access to details about License Management in OpsCompass.

### Credential Commands

`get-secret-for-configuration`  
Gets a secret for a single configuration passed.  
**Parameters:**  
--id \[vcenter\_configuration\_id | oracle\_database\_configuration\_id | msql\_configuration\_id | msql\_default\_credential\_id | oracle\_default\_credential\_id\]  
--record-type \['oracle\_database\_configuration' | 'vcenter\_configuration' | 'msql\_configuration' | 'msql\_shared\_monitoring\_credential' | 'oracle\_shared\_monitoring\_credential'

`create-oracle-shared-credential`  
Creates Oracle shared credentials  
--monitoring-configuration-id monitoring configuration ID to make the shared credentials for  
--user (optional) \[string\]  
--password (optional) \[string\]

`delete-oracle-shared-credential`  
Delete a Oracle shared credential  
--id ID of the oracle shared credential to delete

`get-oracle-default-credential`  
Get Oracle default credential record. This optional default can be set to serve as your default credential. Any individual connection string can override the default credential as needed.  
--monitoring-configuration-id monitoring configuration ID to get the default credentials for example:  
`opscompass license-manager get-oracle-default-credential`

`update-oracle-shared-credential`  
Update Oracle shared credential record  
--id ID of the oracle shared credential to update  
--user (optional) \[string\]  
--password (optional) \[string\]

`create-msql-shared-credential Creates`  
MSQL shared credentials  
--monitoring-configuration-id monitoring configuration ID to make the shared credentials for  
--user (optional) \[string\]  
--password (optional) \[string\]  
--directory-auth (optional) 'SESSION' | null

`delete-msql-shared-credential`  
Delete a MSQL shared credential  
--id ID of the msql shared credential to delete

`get-msql-default-credential`  
Get MSQL default credential record  
--monitoring-configuration-id monitoring configuration ID to get the default credentials for

`update-msql-shared-credential`  
Update MSQL shared credential record  
--id ID of the msql shared credential to update  
--user (optional) \[string\]  
--password (optional) \[string\]  
--directory-auth (optional) 'SESSION' | null

### Monitoring Configuration Commands

These are called “Data Gathering Configuration” in Opscompass. Most companies will only have one configuration, but you can create more if desired.

`list-monitoring-configurations`  
Lists all of the monitoring configurations associated with the given company.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)

`get-monitoring-configuration`  
Get a single monitoring configuration associated with the given company.  
**Parameters:**  
--id \[monitoring\_configuration\_id\]  
--asFile (optional) {true|false} - fetch configuration as a file  
--saveFile (optional) {true|false} \[save-path\] - save configuration (implies asFile)

`read-monitoring-configuration`  
Reads a local monitoring configuration associated with the given company.  
**Parameters:**  
--id \[monitoring\_configuration\_id\]  
--list-details - return the file metadata

`create-monitoring-configuration`  
Create a single monitoring configuration associated with the given company.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)  
--configurationName \[configuration name\]  
--autoUpdateScripts (optional) \[true | false\] automatically update all scripts when the scripts are run. --autoUpdateConfigurations (optional) \[true | false\] automatically update all configurations when scripts are run.

`update-monitoring-configuration`  
Update a single monitoring configuration. You may find it easier to use the Opscompass web interface for this command  
**Parameters:**  
--id \[monitoring\_configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--autoUpdateConfigurations (optional) \[true | false\]  
--autoUpdateScripts (optional) \[true | false\]  
--dataFileRetainDays (optional) \[determines how many days to retain encrypted output files locally\]   
--dataFileRetainTextDays (optional) \[determines how many days to retain individual script output files locally\]  
--forceFileEncryption (optional) \[enforce encryption of datafiles before being sent\]  
--dataFileTag (optional) \[used to help filename generation to prevent duplicate file names\]   
--mailFrom (optional) \[Use parameter multiple times to send multiple email addresses. Identifies sender's email addresses when file delivery is done through email.\]  
--emailTo (optional) \[Use parameter multiple times to send multiple email addresses. Identifies the destination email addresses when file delivery is done through email.\]   
--notificationEmailTo (optional) \[Use parameter multiple times to send multiple email addresses. Identifies the destination email addresses when notifications are sent.\]  
--logFileRetainDays (optional) \[determines how many days to retain log files locally\]  
--logFileTag (optional) \[used to help filename generation to prevent duplicate file names\]

`mask-monitoring-configurations`  
Tools for managing sensitive data associated with the given company. Most companies will not need this. If you wish to enable masking, contact Opscompass support for more information.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)

Actions available for maskValues:  
`dumpTable` : dumps the mask table for the specified property       
`lookup`: gets a value from mask           
`set`: sets a value to mask

**Parameters:**  
  --type ( md5 | sha256 )   \[required\]   property\[=value\]   \[required\]

### Configuration commands – read and list

These are simple GET and LIST commands for the various configuration types.

`list-oracle-database-configurations`  
Lists all of the oracle database configurations associated with the given monitoring configuration  
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]

`get-oracle-database-configuration`  
Get a single oracle database configuration associated with the given monitoring configuration  
**Parameters:**  
--id \[oracle\_database\_configuration\_id\]

`list-vcenter-configurations`  
Lists all of the vcenter configurations associated with the given monitoring configuration   
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]

`get-vcenter-configuration`  
Get a single vcenter configuration associated with the given monitoring configuration  
**Parameters:**  
--id \[vcenter\_configuration\_id\]

`get-msql-configuration`  
Get a single msql configuration associated with the given monitoring configuration  
**Parameters:**  
--id \[msql\_configuration\_id\]

`list-msql-configurations`  
Lists all of the msql configurations associated with the given monitoring configuration  
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]

`get-network-discovery-configuration`  
Get a single network discovery configuration.  
**Parameters:**  
--id \[network\_discovery\_configuration\_id\]

### Configuration commands – create

Create a ‘configuration’ (aka a connection string) to a specific type of resource such as Oracle database or VCenter. These commands can be used as part of a database onboarding automation workflow.

You may find it easier to create and update connections using the Opscompass web interface.

`create-vcenter-configuration`  
Create a single vcenter configuration associated with the given monitoring configuration.  
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]  
--name \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. –action "skip" --action "vmotion"  
--connection (optional) \[the hostname or ip address\]  
--user (optional) \[connection username\]  
--password (optional) \[connection password\]

`create-oracle-database-configuration`  
Create a single oracle database configuration associated with the given monitoring configuration.  
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]  
--configuration-name \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. –action "skip" --action "dbcompliance"  
--user (optional) \[user to use for connection\]  
--password (optional) \[password to use for connection\]  
--server (optional) \[server to use for connection\]

`create-msql-configuration`  
Create a single msql configuration associated with the given monitoring configuration.  
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]  
--name or --configuration-name \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. –action "skip" --action "dbcompliance"  
--server (optional) \[the hostname or ip address\]  
--user (optional) \[connection username\]  
--password (optional) \[connection password\]  
--directory-auth (optional) \['SESSION' or NULL\]

`create-network-discovery-configuration`  
Creates a new networking discovery configuration associated with the given monitoring configuration. This is a litle-used feature.  
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]  
--oracle-ports (optional) comma seperated list of valid port numbers to look for oracle connections  
--mssql-ports (optional) comma seperated list of valid port numbers to look for mssql connections --other-ports (optional) comma seperated list of valid port numbers to look for misc connections --dns-servers (optional) comma seperated list of valid IPV4 DNS servers to use for DNS resolution.  
Can be specified multiple times  
--subnet (optional) If supplied --subnet-name is also required. Valid IPV4 CIDR block as an input.  
Can be supplied multiple times  
--subnet-name (optional) If supplied --subnet is also required. Name for the next/last subnet block provided. Can be supplied multiple times.

### Configuration commands – update

Update a ‘configuration’ (aka a connection string) to a specific type of resource such as Oracle database or VCenter. These commands are complex and require advanced knowledge of JSON formats and parameter passing. You may find it easier to create and update connections using the Opscompass web interface.

`update-vcenter-configuration`  
Update a single vcenter configuration.  
**Parameters:**  
--id \[configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. --action  
'skip' --action 'vmotion'\]  
--connection (optional) \[the hostname or ip address\]  
--user (optional) \[connection username\]  
--password (optional) \[connection password\]

`update-vcenter-configurations`  
Bulk Update multiple vcenter configurations.  
**Parameters:**  
--id \[configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. --action  
 "skip" --action "vmotion"  
--connection (optional) \[the hostname or ip address\]  
--user (optional) \[connection username\]  
--password (optional) \[connection password\]  
OR --json-updates \[stringified json objects with your updates\]

For quick updates, you may use the above parameters e.g. 

```
opscompass license-manager update-vcenter-configurations --id 137 --name"updatedName" --id 138 --name "otherUpdatedName" --id 144 --name"lastUpdatedName" --action "skip" --action "vmotion";
```

For larger updates, JavaScript Object Notation (JSON) may be used with the --json-updates flag e.g.

```

```

 

`update-oracle-database-configuration`  
Update a single oracle database configuration.  
**Parameters:**  
--id \[configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take --action  
"skip" --action "dbcompliance"  
--user (optional) \[user to use for connection\]  
--password (optional) \[password to use for connection\] --server (optional) \[server to use for connection\]

`update-oracle-database-configurations`  
Bulk update multiple oracle database configurations.  
**Parameters:**  
--id \[configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. --action  
"skip" --action "dbcompliance"  
--user (optional) \[the user to use for the connection\]  
--password (optional) \[the password to use for the connection\]  
--server (optional) \[the server to use for the connection\]  
OR --json-updates \[stringified json objects with your updates\]

For quick updates, you may use the above parameters e.g. 

```
opscompass license-manager update-oracle-database-configurations --id 57 -name "updatedName" --id 62 --name "otherUpdatedName" --id 77 --name"lastUpdatedName" ;
```

For larger updates, JavaScript Object Notation (JSON) may be used with the --json-updates flag e.g.

```
 opscompass license-manager update-oracle-database-configurations --jsonupdates '[{"id":"57","configurationName":"updatedName"},{"id":"77", "configurationName":"otherUpdatedName", "action":"null"},{"id":"79","configurationName":"lastUpdatedName"}]'
```

`update-msql-configuration`  
Update a single msql configuration.  
**Parameters:**  
--id \[configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take   
e.g. --action  
'skip' --action 'dblicensing'  
--server (optional) \[the server\]  
--user (optional) \[connection username\]  
--password (optional) \[connection password\]  
--directory-auth (optional) \['SESSION' or NULL\]

For quick updates, you may use the above parameters e.g.

```
opscompass license-manager update-msql-configurations --id 31 --name "newname" --server "233.533.343" --user "joe" --action "skip" --id 25 --name"secondname" --action "skip" --action "dblicensing"
```

For larger updates, JavaScript Object Notation (JSON) may be used with the --json-updates flag e.g.

```
opscompass license-manager update-msql-configurations --json-updates '[{"id":"25","configurationName":"25", "server":"100.232.2423", "user":"tony","actions":["skip", "dblicensing"]}, {"id":"31","configurationName":"31","server":"100.232.2423", "user":"tony", "actions":["skip", "dblicensing"]}]'
```

`update-msql-configurations`  
Bulk Update Msql Configurations.  
**Parameters:**  
--id \[configuration id\]  
--name or --configuration-name (optional) \[unique name\]  
--action (optional) pass multiple times to define which actions this connection can take e.g. --action  
'skip' --action 'dblicensing'  
--server (optional) \[the server\]  
--user (optional) \[connection username\]  
--password (optional) \[connection password\]  
--directory-auth (optional) \['SESSION' or NULL\]  
OR --json-updates \[stringified json objects with your updates\]

`update-network-discovery-configuration`  
Updates an existing networking discovery configuration. If an optional parameter is not provided, it is assumed that the field should be set to undefined. This is a litle-used feature. You may find it easier to use the Opscompass web interface for this command.  
**Parameters:**  
--id \[network\_discovery\_configuration\_id\]  
--oracle-ports (optional) comma seperated list of valid port numbers to look for oracle connections  
--mssql-ports (optional) comma seperated list of valid port numbers to look for mssql connections --other-ports (optional) comma seperated list of valid port numbers to look for misc connections --dns-servers (optional) comma seperated list of valid IPV4 DNS servers to use for DNS resolution.

Can be specified multiple times  
--subnet (optional) If supplied --subnet-name is also required. Valid IPV4 CIDR block as an input.

Can be supplied multiple times  
--subnet-name (optional) If supplied --subnet is also required. Name for the next/last subnet block provided. Can be supplied multiple times.

### Configuration commands – delete

`delete-monitoring-configuration`  
Delete a monitoring configuration   
Parameters:  
--id \[monitoring\_configuration\_id\]

`delete-network-discovery-configuration`  
Delete a network discovery configuration   
Parameters:  
--id \[network\_discovery\_configuration\_id\] 

`delete-oracle-database-configuration`  
Delete a oracle database configuration   
Parameters:  
--id \[oracle\_database\_configuration\_id\] 

`delete-vcenter-configuration`  
Delete a vcenter configuration   
**Parameters:**  
--id \[vcenter\_configuration\_id\]

`delete-msql-configuration`  
Delete a msql configuration   
**Parameters:**  
--id \[msql\_configuration\_id\]

### Configuration commands – MS SQL entitlements

You may find it easier to create and update entitlement information using the Opscompass web interface.  If the Opscompass staff already has your license entitlement information, you do not need to add it again.

`get-mssql-entitlement-components`  
Gets the components that can be used to build MSSql entitlement objects.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)

`create-mssql-entitlement`  
Creates a Mssql Entitlement record.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass) --purchase-date \[Date\] the date of purchase.  
Format: UTC, example: '2022-08-23T17:00:00Z' to set August 8th, 2022 at 17:00 UTC.  
--quantity \[number\] the number for this entry  
--support-start (optional) \[Date\] the date when support started  
Format: UTC, example: '2022-08-23T17:00:00Z' to set August 8th, 2022 at 17:00 UTC.  
--support-end (optional) \[Date\] the date when support ended  
Format: UTC, example: '2022-08-23T17:00:00Z' to set August 8th, 2022 at 17:00 UTC.  
--mssql-product \[string\] the slug of the associated mssql product  
--mssql-edition \[string\] the slug of the associated mssql edition  
--mssql-version \[string\] the slug of the associated mssql version  
--mssql-metric \[string\] the slug of the associated mssql metric

`update-mssql-entitlement`  
Creates a Mssql Entitlement record.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)  
--id \[number\] the mssql entitlement record id  
--purchase-date \[Date\] the date of purchase.  
Format: UTC, example: '2022-08-23T17:00:00Z' to set August 8th, 2022 at 17:00 UTC.  
--quantity \[number\] the number for this entry  
--support-start (optional) \[Date\] the date when support started  
Format: UTC, example: '2022-08-23T17:00:00Z' to set August 8th, 2022 at 17:00 UTC.  
--support-end (optional) \[Date\] the date when support ended  
Format: UTC, example: '2022-08-23T17:00:00Z' to set August 8th, 2022 at 17:00 UTC.  
--mssql-product \[string\] the slug of the associated mssql product  
--mssql-edition \[string\] the slug of the associated mssql edition  
--mssql-version \[string\] the slug of the associated mssql version  
--mssql-metric \[string\] the slug of the associated mssql metric

`delete-mssql-entitlements`  
Deletes Mssql Entitlement records.  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)  
--id \[string\] Use parameter multiple times to delete multiple records.

### Configuration commands – MS SQL assessments

Advanced commands to be used only at the direction of Opscompass staff.

`list-mssql-assessments`  
Lists MSSQL Assessments  
**Parameters:**  
--company \[company\_slug\] (default: opscompass)

`get-mssql-assessment`  
Get Full MSSQL Assessment  
**Parameters:**  
--assessmentId \[number\] The id of the assessment to retrieve.

`get-mssql-assessment-entitlements`  
Gets Entitlements for an MSSQL Assessment  
**Parameters:**  
--assessmentId \[number\] The id of the assessment to retrieve.

`(DEPRECATED) get-mssql-assessment-license-usage-maps`  
Gets LicenseUsageMaps for an MSSQL Assessment  
**Parameters:**  
--assessmentId \[number\] The id of the assessment to retrieve.

`(DEPRECATED) get-mssql-assessment-resources`  
Gets Resources for an MSSQL Assessment  
**Parameters:**  
--assessmentId \[number\] The id of the assessment to retrieve.

`check-mssql-config-metadata`  
Checks the mssql configuration metadata for a company. Mostly used for troubleshooting. It will dump a list of metadata about each MSSQL Connection that you have defined.  
**Parameters:**  
--accountId \[string\] The account id for the company.  
--company \[company\_slug\] (default: opscompass)  
--lastCollectedBefore \[string\] (optional) Only returns records that have not been collected since the given date. Format: UTC, example: '2022-08-23T17:00:00Z'

`check-oracle-config-metadata`  
Checks the oracle configuration metadata for a company. Mostly used for troubleshooting. It will dump a list of metadata about each Oracle Connection that you have defined.  
**Parameters:**  
--accountId \[string\] The account id for the company.  
--company \[company\_slug\] (default: opscompass)  
--lastCollectedBefore \[string\] (optional) Only returns records that have not been collected since the given date. Format: UTC, example: '2022-08-23T17:00:00Z'  
--monitoring-configuration-id \[monitoring\_configuration\_id\]

`get-vcenter-configuration`  
Get a single vcenter configuration associated with the given monitoring configuration   
**Parameters:**  
--id \[vcenter\_configuration\_id\]

`get-msql-configuration`  
Get a single msql configuration associated with the given monitoring configuration  
**Parameters:**  
--id \[msql\_configuration\_id\]

`list-msql-configurations`  
Lists all of the msql configurations associated with the given monitoring configuration   
**Parameters:**  
--monitoring-configuration-id \[monitoring\_configuration\_id\]

`get-network-discovery-configuration`  
Get a single network discovery configuration.  
**Parameters:**  
--id \[network\_discovery\_configuration\_id\]

- [About Opscompass](https://kb.opscompass.com/knowledge/about-opscompass#main-content)

    - [Company Information](https://kb.opscompass.com/knowledge/about-opscompass#company-information)
- [Getting Started](https://kb.opscompass.com/knowledge/getting-started#main-content)

    - [Logging In](https://kb.opscompass.com/knowledge/getting-started#logging-in)
    - [Connecting Cloud Accounts](https://kb.opscompass.com/knowledge/getting-started#connecting-cloud-accounts)
    - [Users and Teams](https://kb.opscompass.com/knowledge/getting-started#users-and-teams)
- [Opscompass CLI](https://kb.opscompass.com/knowledge/opscompass-cli#main-content)

    - [Getting Started](https://kb.opscompass.com/knowledge/opscompass-cli#getting-started)
    - [Resources](https://kb.opscompass.com/knowledge/opscompass-cli#resources)
    - [Accounts](https://kb.opscompass.com/knowledge/opscompass-cli#accounts)
    - [Compliance](https://kb.opscompass.com/knowledge/opscompass-cli#compliance)
    - [Licensing](https://kb.opscompass.com/knowledge/opscompass-cli#licensing)
    - [Examples](https://kb.opscompass.com/knowledge/opscompass-cli#examples)
    - [AI Skills](https://kb.opscompass.com/knowledge/opscompass-cli#ai-skills)
- [Opscompass FAQs](https://kb.opscompass.com/knowledge/opscompass-faqs#main-content)

    - [General](https://kb.opscompass.com/knowledge/opscompass-faqs#general)
- [New Features](https://kb.opscompass.com/knowledge/new-features)
- [Account Management](https://kb.opscompass.com/knowledge/account-management)
- [Compliance](https://kb.opscompass.com/knowledge/compliance)
- [Documents](https://kb.opscompass.com/knowledge/documents)
- [Drift](https://kb.opscompass.com/knowledge/drift)
- [Inventory](https://kb.opscompass.com/knowledge/inventory)
- [Licenses](https://kb.opscompass.com/knowledge/licenses#main-content)

    - [Oracle](https://kb.opscompass.com/knowledge/licenses#oracle)
    - [SQL Server](https://kb.opscompass.com/knowledge/licenses#sql-server)
- [Navigation and Dashboard](https://kb.opscompass.com/knowledge/navigation-and-dashboard)
- [Opscompass Integrations](https://kb.opscompass.com/knowledge/opscompass-integrations)
- [Tutorials](https://kb.opscompass.com/knowledge/tutorials#main-content)

    - [CLI](https://kb.opscompass.com/knowledge/tutorials#cli)

[![Opscompass](https://kb.opscompass.com/hubfs/opscompass-logo-2024-web-small.svg "Opscompass")](http://opscompass.com)

<https://opscompass.com/contact/> <https://www.linkedin.com/company/opscompass/>

Copyright © 2025, Opscompass